@@ -55,11 +55,11 @@ func (c *Container) List(ctx context.Context, _ string) ([]runtime.Object, error
 }
 
 // TailLogs tails a given container logs.
-func (c *Container) TailLogs(ctx context.Context, logChan LogChan, opts *LogOptions) error {
+func (c *Container) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, error) {
 	po := Pod{}
 	po.Init(c.Factory, client.NewGVR("v1/pods"))
 
-	return po.TailLogs(ctx, logChan, opts)
+	return po.TailLogs(ctx, opts)
 }
 
 // ----------------------------------------------------------------------------
