@@ -45,7 +45,7 @@ func (Node) Header(_ string) Header {
 		HeaderColumn{Name: "MEM/A", Align: tview.AlignRight, MX: true},
 		HeaderColumn{Name: "LABELS", Wide: true},
 		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true, Decorator: AgeDecorator},
+		HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
