@@ -29,7 +29,7 @@ func (NetworkPolicy) Header(ns string) Header {
 		HeaderColumn{Name: "EGR-BLOCK"},
 		HeaderColumn{Name: "LABELS", Wide: true},
 		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true, Decorator: AgeDecorator},
+		HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
