@@ -23,7 +23,7 @@ func (ServiceAccount) Header(ns string) Header {
 		HeaderColumn{Name: "SECRET"},
 		HeaderColumn{Name: "LABELS", Wide: true},
 		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true, Decorator: AgeDecorator},
+		HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
