@@ -21,7 +21,7 @@ func (StorageClass) Header(ns string) Header {
 		HeaderColumn{Name: "PROVISIONER"},
 		HeaderColumn{Name: "LABELS", Wide: true},
 		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true, Decorator: AgeDecorator},
+		HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
